"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FD = void 0;
const net_1 = __importDefault(require("net"));
const log_1 = require("../log");
const shell_1 = require("../shell");
const delay_1 = require("../delay");
class FD {
    constructor(bin, width, height, host, port) {
        this.socketAvailable = false;
        this.socketConnected = false;
        this.bin = bin;
        this.width = width;
        this.height = height;
        this.host = host;
        this.port = port;
        this.log = (0, log_1.createLog)('fd');
        this.shell = new shell_1.Shell([this.bin, `${this.width}`, `${this.height}`], this.logstd.bind(this), this.logsterr.bind(this), null, true);
        this.startDisplay();
        this.startClient();
        this.test();
    }
    async startDisplay() {
        this.log.info(`Launching fd binary ${this.bin}`);
        this.shell.execute();
    }
    async startClient() {
        this.client = new net_1.default.Socket();
        this.log.info(`Waiting for TCP socket server on ${this.host}:${this.port}...`);
        while (!this.socketAvailable) {
            await (0, delay_1.delay)(10);
        }
        this.log.info(`TCP socket server on ${this.host}:${this.port} is available`);
        this.client.connect(this.port, this.host, async function () {
            this.socketConnected = true;
            this.log.info(`TCP socket client connected to ${this.host}:${this.port}`);
            /*const data = {
                action : 1,
                image: 'filename.tif',
            };
            this.log.info('SENDING');
            this.log.info(data);
            this.client.write(JSON.stringify(data));
            await delay(2000);
            data.action = 2;
            this.log.info('SENDING');
            this.log.info(data);
            this.client.write(JSON.stringify(data));*/
        }.bind(this));
        this.client.on('data', (data) => {
            this.log.info('RECEIVED');
            this.log.info(data.toString());
        });
        this.client.on('close', () => {
            this.log.info('Closing connection');
        });
        this.client.on('error', (err) => {
            this.log.error('Error:', err);
        });
    }
    logstd(data) {
        this.log.info(data);
        if (data.indexOf('TCP server listening on port') !== -1 && data.indexOf(`${this.port}`) !== -1) {
            this.socketAvailable = true;
        }
    }
    logsterr(data) {
        this.log.error(data);
    }
    async test() {
        await (0, delay_1.delay)(10000);
        this.shell.kill();
    }
}
exports.FD = FD;
//# sourceMappingURL=index.js.map