import type { Logger } from 'winston';
import net from 'net';
import type { Socket } from 'net';
import { createLog } from '../log'
import { Shell } from '../shell';
import { delay } from '../delay';

export class FD {
	private bin : string;
	private width : number;
	private height : number;
	private host : string;
	private port : number;
	private shell : Shell;
	private log : Logger;
	private client : Socket;
	private socketAvailable : boolean = false;
	private socketConnected : boolean = false;

	constructor (bin: string, width : number, height : number, host : string, port : number) {
		this.bin = bin;
		this.width = width;
		this.height = height;
		this.host = host;
		this.port = port;
		this.log = createLog('fd');
		this.shell = new Shell([ this.bin, `${this.width}`, `${this.height}` ], this.logstd.bind(this), this.logsterr.bind(this), null, true);
		this.startDisplay();
		this.startClient();
		this.test();
	}

	private async startDisplay () {
		this.log.info(`Launching fd binary ${this.bin}`);
		this.shell.execute();
	}

	private async startClient () {
		this.client = new net.Socket();
		this.log.info(`Waiting for TCP socket server on ${this.host}:${this.port}...`);
		while (!this.socketAvailable) {
			await delay(10);
		}
		this.log.info(`TCP socket server on ${this.host}:${this.port} is available`);
		this.client.connect(this.port, this.host, async function () {
			this.socketConnected = true;
			this.log.info(`TCP socket client connected to ${this.host}:${this.port}`);
			/*const data = {
				action : 1,
				image: 'filename.tif',
			};
			this.log.info('SENDING');
			this.log.info(data);
			this.client.write(JSON.stringify(data));
			await delay(2000);
			data.action = 2;
			this.log.info('SENDING');
			this.log.info(data);
			this.client.write(JSON.stringify(data));*/
		}.bind(this));

		this.client.on('data', (data : string) => {
		    this.log.info('RECEIVED');
		    this.log.info(data.toString());
		});

		this.client.on('close', () => {
		    this.log.info('Closing connection');
		});

		this.client.on('error', (err : Error) => {
		    this.log.error('Error:', err);
		});
	}

	private logstd ( data : string ) {
		this.log.info(data);
		if (data.indexOf('TCP server listening on port') !== -1 && data.indexOf(`${this.port}`) !== -1) {
			this.socketAvailable = true;
		}
	}

	private logsterr ( data : string) {
		this.log.error(data);
	}

	private async test () {
		await delay(10000);
		this.shell.kill();
	}
}

